@@ -2,7 +2,7 @@
 
 package MooseX::GlobRef::Meta::Class;
 
-=head1 NAME 
+=head1 NAME
 
 MooseX::GlobRef::Meta::Class - Metaclass for globref objects
 
@@ -17,7 +17,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = 0.04;
+our $VERSION = '0.05';
 
 
 use parent 'Moose::Meta::Class';
@@ -28,13 +28,45 @@ use parent 'Moose::Meta::Class';
 
 __END__
 
-=head1 BASE CLASSES
+=head1 INHERITANCE
 
 =over 2
 
 =item *
 
-L<Moose::Meta::Class>
+extends L<Moose::Meta::Class>
+
+=over 2
+
+=item   *
+
+extends L<Class::MOP::Class>
+
+=over 2
+
+=item     *
+
+extends L<Class::MOP::Module>
+
+=over 2
+
+=item       *
+
+extends L<Class::MOP::Package>
+
+=over 2
+
+=item         *
+
+extends L<Class::MOP::Object>
+
+=back
+
+=back
+
+=back
+
+=back
 
 =back
 
@@ -44,11 +76,11 @@ L<MooseX::GlobRef::Object>, L<Moose::Meta::Object>, L<Moose>, L<metaclass>.
 
 =head1 AUTHOR
 
-Piotr Roszatycki E<lt>dexter@debian.orgE<gt>
+Piotr Roszatycki <dexter@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2007, 2008 by Piotr Roszatycki E<lt>dexter@debian.orgE<gt>.
+Copyright (C) 2007, 2008, 2009 by Piotr Roszatycki E<lt>dexter@debian.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
