@@ -2,7 +2,7 @@
 
 package MooseX::GlobRef::Meta::Instance;
 
-=head1 NAME 
+=head1 NAME
 
 MooseX::GlobRef::Meta::Instance - Instance metaclass for globref objects
 
@@ -10,8 +10,9 @@ MooseX::GlobRef::Meta::Instance - Instance metaclass for globref objects
 
   package My::IO;
 
-  use metaclass 'Moose::Meta::Class' =>
-      instance_metaclass => 'MooseX::GlobRef::Meta::Instance';
+  use metaclass 'Moose::Meta::Class' => (
+      instance_metaclass => 'MooseX::GlobRef::Meta::Instance'
+  );
 
   use Moose;
 
@@ -19,8 +20,7 @@ MooseX::GlobRef::Meta::Instance - Instance metaclass for globref objects
 
   sub open {
     my $fh = shift;
-    my $hashref = ${*$fh};
-    open $fh, $hashref->{file} or confess "cannot open";
+    open $fh, $fh->file or confess "cannot open";
     return $fh;
   };
 
@@ -35,14 +35,14 @@ MooseX::GlobRef::Meta::Instance - Instance metaclass for globref objects
   print "::::::::::::::\n";
   $io->open;
   print $io->getlines;
-  
+
 =head1 DESCRIPTION
 
-This instance metaclass allows to store Moose object in glob reference or
-file handle.  It can be used directly with B<metaclass> pragma or with
+This instance metaclass allows to store Moose object in glob reference of
+file handle.  It can be used directly with C<metaclass> pragma or with
 L<MooseX::GlobRef::Object> base class.
 
-Notice, that "use metaclass" have to be before "use Moose".
+Notice, that C<use metaclass> have to be before C<use Moose>.
 
 =cut
 
@@ -50,7 +50,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = 0.04;
+our $VERSION = '0.05';
 
 
 use parent 'Moose::Meta::Instance';
@@ -59,55 +59,55 @@ use parent 'Moose::Meta::Instance';
 sub create_instance {
     my ($self) = @_;
 
-    # create anonymous filehandler
-    select select my $fh;
+    # create anonymous file handle
+    select select my $instance;
 
-    # associate hashref with globref
-    ${*$fh} = {};
+    # initialize hash slot of file handle
+    %{*$instance} = ();
 
-    return bless $fh => $self->associated_metaclass->name;
+    return bless $instance => $self->associated_metaclass->name;
 };
 
 
 sub get_slot_value {
     my ($self, $instance, $slot_name) = @_;
-    return ${*$instance}->{$slot_name};
+    return do { \%{*$instance} }->{$slot_name};
 };
 
 
 sub set_slot_value {
     my ($self, $instance, $slot_name, $value) = @_;
-    return ${*$instance}->{$slot_name} = $value;
+    return do { \%{*$instance} }->{$slot_name} = $value;
 };
 
 
 sub deinitialize_slot {
     my ( $self, $instance, $slot_name ) = @_;
-    return delete ${*$instance}->{$slot_name};
+    return delete do { \%{*$instance} }->{$slot_name};
 };
 
 
 sub is_slot_initialized {
     my ($self, $instance, $slot_name) = @_;
-    return exists ${*$instance}->{$slot_name} ? 1 : 0;
+    return exists do { \%{*$instance} }->{$slot_name};
 };
 
 
 sub weaken_slot_value {
     my ($self, $instance, $slot_name) = @_;
-    return Scalar::Util::weaken ${*$instance}->{$slot_name};
+    return Scalar::Util::weaken do { \%{*$instance} }->{$slot_name};
 };
 
 
 sub inline_create_instance {
     my ($self, $class_variable) = @_;
-    return 'select select my $fh; ${*$fh} = {}; bless $fh => ' . $class_variable;
+    return 'select select my $fh; %{*$fh} = (); bless $fh => ' . $class_variable;
 };
 
 
 sub inline_slot_access {
     my ($self, $instance, $slot_name) = @_;
-    return sprintf '${*{%s}}->{%s}', $instance, $slot_name;
+    return 'do { \%{*{' . $instance . '}} }->{' . $slot_name . '}';
 };
 
 
@@ -116,13 +116,29 @@ sub inline_slot_access {
 
 __END__
 
-=head1 BASE CLASSES
+=head1 INHERITANCE
 
 =over 2
 
 =item *
 
-L<Moose::Meta::Instance>
+extends L<Moose::Meta::Instance>
+
+=over 2
+
+=item   *
+
+extends L<Class::MOP::Instance>
+
+=over 2
+
+=item     *
+
+extends L<Class::MOP::Object>
+
+=back
+
+=back
 
 =back
 
@@ -156,11 +172,11 @@ L<MooseX::GlobRef::Object>, L<Moose::Meta::Instance>, L<Moose>, L<metaclass>.
 
 =head1 AUTHOR
 
-Piotr Roszatycki E<lt>dexter@debian.orgE<gt>
+Piotr Roszatycki <dexter@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2007, 2008 by Piotr Roszatycki E<lt>dexter@debian.orgE<gt>.
+Copyright (C) 2007, 2008, 2009 by Piotr Roszatycki E<lt>dexter@debian.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
